@@ -1,8 +1,10 @@
 describe("module:ng.directive:ngRepeat", function() {
+  var rootEl;
   beforeEach(function() {
+    rootEl = browser.rootEl;
     browser.get("./examples/example-example41/index-jquery.html");
   });
-
+  
 var friends = element.all(by.repeater('friend in friends'));
 
 it('should render initial data set', function() {
@@ -23,4 +25,4 @@ it('should render initial data set', function() {
    expect(friends.get(0).getText()).toEqual('[1] Mary who is 28 years old.');
    expect(friends.last().getText()).toEqual('[2] Samantha who is 60 years old.');
  });
-});
\ No newline at end of file
+});
