@@ -1,8 +1,10 @@
 describe("module:ng.directive:ngSwitch", function() {
+  var rootEl;
   beforeEach(function() {
+    rootEl = browser.rootEl;
     browser.get("./examples/example-example45/index.html");
   });
-
+  
   var switchElem = element(by.css('[ng-switch]'));
   var select = element(by.model('selection'));
 
@@ -10,11 +12,11 @@ describe("module:ng.directive:ngSwitch", function() {
     expect(switchElem.getText()).toMatch(/Settings Div/);
   });
   it('should change to home', function() {
-    select.element.all(by.css('option')).get(1).click();
+    select.all(by.css('option')).get(1).click();
     expect(switchElem.getText()).toMatch(/Home Span/);
   });
   it('should select default', function() {
-    select.element.all(by.css('option')).get(2).click();
+    select.all(by.css('option')).get(2).click();
     expect(switchElem.getText()).toMatch(/default/);
   });
-});
\ No newline at end of file
+});
