@@ -1,8 +1,10 @@
 describe("module:ng.directive:ngTransclude", function() {
+  var rootEl;
   beforeEach(function() {
+    rootEl = browser.rootEl;
     browser.get("./examples/example-example46/index-jquery.html");
   });
-
+  
    it('should have transcluded', function() {
      var titleElement = element(by.model('title'));
      titleElement.clear();
@@ -13,4 +15,4 @@ describe("module:ng.directive:ngTransclude", function() {
      expect(element(by.binding('title')).getText()).toEqual('TITLE');
      expect(element(by.binding('text')).getText()).toEqual('TEXT');
    });
-});
\ No newline at end of file
+});
