@@ -1,9 +1,11 @@
 describe("module:ng.filter:json", function() {
+  var rootEl;
   beforeEach(function() {
+    rootEl = browser.rootEl;
     browser.get("./examples/example-example54/index-jquery.html");
   });
-
+  
   it('should jsonify filtered objects', function() {
     expect(element(by.binding("{'name':'value'}")).getText()).toMatch(/\{\n  "name": ?"value"\n}/);
   });
-});
\ No newline at end of file
+});
