@@ -1,8 +1,10 @@
 describe("module:ng.input:input[url]", function() {
+  var rootEl;
   beforeEach(function() {
+    rootEl = browser.rootEl;
     browser.get("./examples/example-url-input-directive/index.html");
   });
-
+  
   var text = element(by.binding('text'));
   var valid = element(by.binding('myForm.input.$valid'));
   var input = element(by.model('text'));
@@ -26,4 +28,4 @@ describe("module:ng.input:input[url]", function() {
 
     expect(valid.getText()).toContain('false');
   });
-});
\ No newline at end of file
+});
